@@ -3,4 +3,4 @@ HapMap.dat <- LDheatmapData[-1,]
 for (LDindex in 1:length(HapMap.dat))
      HapMap.dat[,LDindex] <- genetics::as.genotype(HapMap.dat[,LDindex])
 distance <- as.vector(as.matrix(LDheatmapData[1,]), mode="numeric")
-rm(LDindex)
+rm(LDindex, LDheatmapData)
